.. _debops.backup2l:

debops.backup2l
===============

The ``debops.backup2l`` role manages the `backup2l`__ (backup tool) script.
This script can be used to make automated, incremental archives of a given host
which can be copied to another system as a backup.

.. __: https://github.com/gkiefer/backup2l

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.backup2l/COPYRIGHT


..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
